@@ -212,7 +212,7 @@ query_druid_initialize (QueryDruid *qdruid)
 	gtk_container_set_border_width (GTK_CONTAINER (qdruid), 4);
 
 	/* query which is built during the druid usage */
-	qdruid->priv->build_query = GDA_QUERY (gda_query_new (qdruid->priv->dict));
+	qdruid->priv->build_query = gda_query_new (qdruid->priv->dict);
 	gda_query_set_query_type (qdruid->priv->build_query, GDA_QUERY_TYPE_SELECT);
 
 	g_signal_connect (G_OBJECT (qdruid->priv->build_query), "field_added",
@@ -657,7 +657,7 @@ select_targets_add_table (GtkButton *button, QueryDruid *qdruid)
 			GdaQueryJoin *join;
 
 			/* actual join */
-			join = GDA_QUERY_JOIN (gda_query_join_new_with_targets (qdruid->priv->build_query, otarget, target));
+			join = gda_query_join_new_with_targets (qdruid->priv->build_query, otarget, target);
 			gda_query_join_set_join_type (join, GDA_QUERY_JOIN_TYPE_INNER);
 			gda_query_join_set_condition_from_fkcons (join);
 			gda_query_add_join (qdruid->priv->build_query, join);
@@ -1169,7 +1169,7 @@ sql_query_text_changed_cb (GtkButton *button, QueryDruid *qdruid)
 	GtkWidget *dlg;
 
 	sql = gnome_db_editor_get_all_text (GNOME_DB_EDITOR (qdruid->priv->sql_editor));
-	query = GDA_QUERY (gda_query_new_from_sql (qdruid->priv->dict, sql, &error));
+	query = gda_query_new_from_sql (qdruid->priv->dict, sql, &error);
 	if (gda_query_get_query_type (query) ==  GDA_QUERY_TYPE_NON_PARSED_SQL) {
 		if (error) {
 			str = g_strdup_printf ("<b>%s</b>\n%s", _("Parsing/analyzing error:"), error->message);
@@ -1361,7 +1361,7 @@ finish_page_cb (GnomeDruidPage *page, GtkWidget *druid, QueryDruid *qdruid)
 		const gchar *str;
 
 		sql = gnome_db_editor_get_all_text (GNOME_DB_EDITOR (qdruid->priv->sql_editor));
-		query = GDA_QUERY (gda_query_new_from_sql (qdruid->priv->dict, sql, NULL));
+		query = gda_query_new_from_sql (qdruid->priv->dict, sql, NULL);
 		str = gtk_entry_get_text (GTK_ENTRY (qdruid->priv->query_name));
 		if (str && *str)
 			gda_object_set_name (GDA_OBJECT (query), str);
