@@ -341,7 +341,8 @@ query_editor_initialize (QueryEditor *qedit)
 		/* the query did not have any graph: create one */
 		graph = GDA_GRAPH (gda_graph_query_new (qedit->priv->query));
 		gda_graph_query_sync_targets (GDA_GRAPH_QUERY (graph));
-		gda_dict_assume_object (gda_object_get_dict (GDA_OBJECT (qedit->priv->query)), (GdaObject *) graph);
+		gda_dict_assume_object_as (gda_object_get_dict (GDA_OBJECT (qedit->priv->query)), 
+					   (GdaObject *) graph, GDA_TYPE_GRAPH);
 		g_object_unref (graph);
 	}
 	wid = gnome_db_canvas_query_struct_new (qedit->priv->query, graph);
@@ -533,7 +534,7 @@ sql_query_text_apply_cb (GtkButton *button, QueryEditor *qedit)
 	/* test the new SQL on a temporary query, to be able to let the user change his mind and
 	 * refuse to apply the new SQL text */
 	sql = gnome_db_editor_get_all_text (GNOME_DB_EDITOR (qedit->priv->sql_editor));
-	tmpquery = GDA_QUERY (gda_query_new_copy (query, NULL));
+	tmpquery = gda_query_new_copy (query, NULL);
 	gda_query_set_sql_text (tmpquery, sql, &error);
 
 	if (gda_query_get_query_type (tmpquery) ==  GDA_QUERY_TYPE_NON_PARSED_SQL) {
@@ -612,7 +613,7 @@ select_where_apply_cb (GtkButton *button, QueryEditor *qedit)
 		return;
 	}
 
-	cond = (GdaQueryCondition *) gda_query_condition_new_from_sql (qedit->priv->query, sql, NULL, &error);
+	cond = gda_query_condition_new_from_sql (qedit->priv->query, sql, NULL, &error);
 	if (cond) {
 		gda_query_set_condition (qedit->priv->query, cond);
 		g_object_unref (cond);
