@@ -445,13 +445,13 @@ dtype_info_display_update (GdaDictType *dtype, WsDatatypes *ws)
 			switch (ws->priv->filter_mode) {
 			case 0:
 				if (GDA_IS_DICT_FUNCTION (list->data)) {
-					ldt = gda_dict_function_get_ret_type (GDA_DICT_FUNCTION (list->data));
+					ldt = gda_dict_function_get_ret_dict_type (GDA_DICT_FUNCTION (list->data));
 					getfunc = (ldt == dtype) ? TRUE : FALSE;
 				}
 				break;
 			case 1:
 				if (GDA_IS_DICT_FUNCTION (list->data)) {
-					args = (GSList *) gda_dict_function_get_arg_types (GDA_DICT_FUNCTION (list->data));
+					args = (GSList *) gda_dict_function_get_arg_dict_types (GDA_DICT_FUNCTION (list->data));
 					while (args && !getfunc) {
 						if ((args->data == (gpointer) dtype) || !args->data)
 							getfunc = TRUE;
@@ -461,7 +461,7 @@ dtype_info_display_update (GdaDictType *dtype, WsDatatypes *ws)
 				break;
 			case 2:
 				if (GDA_IS_DICT_AGGREGATE (list->data)) {
-					ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data));
+					ldt = gda_dict_aggregate_get_arg_dict_type (GDA_DICT_AGGREGATE (list->data));
 					getfunc = !ldt || (ldt == dtype) ? TRUE : FALSE;
 				}
 				break;
@@ -479,7 +479,7 @@ dtype_info_display_update (GdaDictType *dtype, WsDatatypes *ws)
 				if (GDA_IS_DICT_FUNCTION (list->data))
 					str = function_get_args (GDA_DICT_FUNCTION (list->data));
 				else {
-					if ((ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data)))) {
+					if ((ldt = gda_dict_aggregate_get_arg_dict_type (GDA_DICT_AGGREGATE (list->data)))) {
 						str = g_strdup_printf (" (%s)", gda_object_get_name (GDA_OBJECT (ldt)));
 					}
 					else
@@ -517,7 +517,7 @@ function_get_args (GdaDictFunction *func)
 	gboolean firstarg = TRUE;
 
 	string = g_string_new ("");
-	args = gda_dict_function_get_arg_types (func);
+	args = gda_dict_function_get_arg_dict_types (func);
 	g_string_append (string, " (");
 	while (args) {
 		if (firstarg)
